@@ -1,6 +1,6 @@
 from django.urls import reverse
 
-from mayan.apps.common.tests.base import GenericViewTestCase
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..links import (
     link_acl_delete, link_acl_list, link_acl_create, link_acl_permissions
@@ -11,9 +11,7 @@ from .mixins import ACLTestMixin
 
 
 class ACLsLinksTestCase(ACLTestMixin, GenericViewTestCase):
-    def setUp(self):
-        super(ACLsLinksTestCase, self).setUp()
-        self._setup_test_object()
+    auto_create_acl_test_object = True
 
     def test_object_acl_create_link(self):
         self.grant_access(
@@ -29,7 +27,7 @@ class ACLsLinksTestCase(ACLTestMixin, GenericViewTestCase):
         self.assertEqual(
             resolved_link.url, reverse(
                 viewname=link_acl_create.view,
-                kwargs=self.test_content_object_view_kwargs
+                kwargs=self.test_object_view_kwargs
             )
         )
 
@@ -48,7 +46,9 @@ class ACLsLinksTestCase(ACLTestMixin, GenericViewTestCase):
 
         self.assertEqual(
             resolved_link.url, reverse(
-                viewname=link_acl_delete.view, args=(self.test_acl.pk,)
+                viewname=link_acl_delete.view, kwargs={
+                    'acl_id': self.test_acl.pk
+                }
             )
         )
 
@@ -67,8 +67,9 @@ class ACLsLinksTestCase(ACLTestMixin, GenericViewTestCase):
 
         self.assertEqual(
             resolved_link.url, reverse(
-                viewname=link_acl_permissions.view,
-                args=(self.test_acl.pk,)
+                viewname=link_acl_permissions.view, kwargs={
+                    'acl_id': self.test_acl.pk
+                }
             )
         )
 
@@ -85,6 +86,6 @@ class ACLsLinksTestCase(ACLTestMixin, GenericViewTestCase):
         self.assertEqual(
             resolved_link.url, reverse(
                 viewname=link_acl_list.view,
-                kwargs=self.test_content_object_view_kwargs
+                kwargs=self.test_object_view_kwargs
             )
         )
