@@ -5,7 +5,8 @@ $.fn.hasAnyClass = function() {
      *  Return true is an element has any of the passed classes
      *  The classes are bassed as an array
      */
-    for (let i = 0; i < arguments[0].length; i++) {
+    const length = arguments[0].length;
+    for (let i = 0; i < length; i++) {
         if (this.hasClass(arguments[0][i])) {
             return true;
         }
@@ -34,6 +35,12 @@ class PartialNavigation {
         // formBeforeSerializeCallbacks - Callbacks to execute before submitting an ajaxForm
         this.formBeforeSerializeCallbacks = parameters.formBeforeSerializeCallbacks || [];
 
+        this.redirectionCode = parameters.redirectionCode;
+
+        if (!this.redirectionCode) {
+            alert('Need to setup redirectionCode');
+        }
+
         if (!this.initialURL) {
             alert('Need to setup initialURL');
         }
@@ -83,7 +90,7 @@ class PartialNavigation {
             url: url,
             type: 'GET',
             success: function (data, textStatus, response){
-                if (response.status == 278) {
+                if (response.status == app.redirectionCode) {
                     // Handle redirects
                     const newLocation = response.getResponseHeader('Location');
 
@@ -117,7 +124,8 @@ class PartialNavigation {
         }
 
         if ($this.hasAnyClass(this.disabledAnchorClasses)) {
-            return false;
+            event.preventDefault();
+            return;
         }
 
         if ($this.parents().hasAnyClass(this.disabledAnchorClasses)) {
@@ -130,12 +138,12 @@ class PartialNavigation {
         }
 
         if (url.indexOf('javascript:;') > -1) {
-            // Ignore links meant to execute javascript on click.
+            // Ignore/exclude links meant to execute javascript on click.
             return true;
         }
 
         if (url === '#') {
-            // Ignore links with hash at the.
+            // Ignore/exclude links with only a hash .
             return true;
         }
 
@@ -242,10 +250,11 @@ class PartialNavigation {
             },
             beforeSubmit: function(arr, $form, options) {
                 const uri = new URI(location);
-                let uriFragment = uri.fragment();
-                let url = $form.attr('action') || uriFragment;
-                let finalUrl = new URI(url);
-                let formQueryString = new URLSearchParams(
+                const uriFragment = uri.fragment();
+                const url = $form.attr('action') || uriFragment;
+                const formAction = new URI(url);
+                let finalUrl = new URI(formAction.path());
+                const formQueryString = new URLSearchParams(
                     decodeURIComponent($form.serialize())
                 );
 
@@ -263,8 +272,11 @@ class PartialNavigation {
                     // If the form has a target attribute we emulate it by
                     // opening a new window and passing the form serialized
                     // data as the query.
-                    let finalUrl = new URI($form.attr('action'));
-                    let formQueryString = new URLSearchParams(decodeURIComponent($form.serialize()));
+                    const formAction = new URI($form.attr('action'));
+                    let finalUrl = new URL(formAction.path());
+                    const formQueryString = new URLSearchParams(
+                        decodeURIComponent($form.serialize())
+                    );
 
                     // Merge the URL and the form values in a smart way instead
                     // of just blindly adding a '?' between them.
@@ -282,15 +294,10 @@ class PartialNavigation {
                 app.processAjaxRequestError(jqXHR);
             },
             mimeType: 'text/html; charset=utf-8', // ! Need set mimeType only when run from local file
-            success: function(data, textStatus, request){
-                if (request.status == 278) {
+            success: function(data, textStatus, request) {
+                if (request.status == app.redirectionCode) {
                     // Handle redirects after submitting the form
-                    let newLocation = request.getResponseHeader('Location');
-                    let uri = new URI(newLocation);
-                    let uriFragment = uri.fragment();
-                    let currentUri = new URI(window.location.hash);
-                    let currentUriFragment = currentUri.fragment();
-                    let url = uriFragment || currentUriFragment;
+                    const newLocation = request.getResponseHeader('Location');
 
                     app.setLocation(newLocation);
                 } else {
@@ -316,16 +323,16 @@ class PartialNavigation {
         // Load ajax content when the hash changes
         if (window.history && window.history.pushState) {
             $(window).on('popstate', function() {
-                let uri = new URI(location);
-                let uriFragment = uri.fragment();
+                const uri = new URI(location);
+                const uriFragment = uri.fragment();
                 app.setLocation(uriFragment, false);
             });
         }
 
         // Load any initial address in the URL of the browser
         if (window.location.hash) {
-            let uri = new URI(window.location.hash);
-            let uriFragment = uri.fragment();
+            const uri = new URI(window.location.hash);
+            const uriFragment = uri.fragment();
             this.setLocation(uriFragment);
         } else {
             this.setLocation('/');
