@@ -1,8 +1,8 @@
-from mayan.apps.document_states.permissions import permission_workflow_edit
+from mayan.apps.document_states.permissions import permission_workflow_template_edit
 from mayan.apps.document_states.tests.base import ActionTestCase
-from mayan.apps.document_states.tests.mixins import (
-    WorkflowStateActionViewTestMixin, WorkflowTestMixin
-)
+from mayan.apps.document_states.tests.mixins.workflow_template_mixins import WorkflowTemplateTestMixin
+from mayan.apps.document_states.tests.mixins.workflow_template_state_mixins import WorkflowTemplateStateActionViewTestMixin
+
 from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..models import Cabinet
@@ -13,7 +13,7 @@ from .mixins import CabinetTestMixin
 
 class CabinetWorkflowActionTestCase(CabinetTestMixin, ActionTestCase):
     def setUp(self):
-        super(CabinetWorkflowActionTestCase, self).setUp()
+        super().setUp()
         self._create_test_cabinet()
 
     def test_cabinet_add_action(self):
@@ -40,14 +40,14 @@ class CabinetWorkflowActionTestCase(CabinetTestMixin, ActionTestCase):
 
 
 class CabinetWorkflowActionViewTestCase(
-    CabinetTestMixin, WorkflowStateActionViewTestMixin, WorkflowTestMixin,
+    CabinetTestMixin, WorkflowTemplateStateActionViewTestMixin, WorkflowTemplateTestMixin,
     GenericViewTestCase
 ):
     def test_cabinet_add_action_create_get_view(self):
-        self._create_test_workflow()
-        self._create_test_workflow_state()
+        self._create_test_workflow_template()
+        self._create_test_workflow_template_state()
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template, permission=permission_workflow_template_edit
         )
 
         response = self._request_test_workflow_template_state_action_create_get_view(
@@ -56,11 +56,11 @@ class CabinetWorkflowActionViewTestCase(
         self.assertEqual(response.status_code, 200)
 
     def test_cabinet_remove_action_create_get_view(self):
-        self._create_test_workflow()
-        self._create_test_workflow_state()
+        self._create_test_workflow_template()
+        self._create_test_workflow_template_state()
         self._create_test_cabinet()
         self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_edit
+            obj=self.test_workflow_template, permission=permission_workflow_template_edit
         )
 
         response = self._request_test_workflow_template_state_action_create_get_view(
