@@ -33,8 +33,8 @@ class ModelCopy:
         return cls._registry[model]
 
     def __init__(
-        self, model, condition=None, bind_link=False, excludes=None,
-        register_permission=False, extra_kwargs=None
+        self, model, acl_bind_link=True, condition=None, bind_link=False,
+        excludes=None, register_permission=False, extra_kwargs=None
     ):
         self.condition = condition
         self.excludes = excludes or {}
@@ -61,7 +61,8 @@ class ModelCopy:
 
         if register_permission:
             ModelPermission.register(
-                model=model, permissions=(permission_object_copy,)
+                model=model, permissions=(permission_object_copy,),
+                bind_link=acl_bind_link
             )
 
         for entry in self.__class__._lazy.get(model, ()):
