@@ -1,10 +1,16 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.dependencies.classes import PythonDependency
+from mayan.apps.dependencies.classes import (
+    BinaryDependency, PythonDependency
+)
 from mayan.apps.dependencies.environments import (
     environment_build, environment_development, environment_documentation,
+    environment_documentation_override
 )
 
+from .literals import DEFAULT_TX_PATH
+
+
 PythonDependency(
     copyright_text='''
         Copyright (c) Django Software Foundation and individual contributors.
@@ -34,7 +40,7 @@ PythonDependency(
         ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
         (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
         SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-    ''', module=__name__, name='django', version_string='==2.2.24'
+    ''', module=__name__, name='django', version_string='==2.2.28'
 )
 PythonDependency(
     copyright_text='''
@@ -116,6 +122,9 @@ PythonDependency(
         CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
     ''', module=__name__, name='django-mptt', version_string='==0.12.0'
 )
+PythonDependency(
+    module=__name__, name='importlib-metadata', version_string='==4.13.0'
+)
 PythonDependency(
     copyright_text='''
         Author: Christian Theune
@@ -151,6 +160,10 @@ PythonDependency(
 
 # Development
 
+BinaryDependency(
+    help_text=_('Transifex Client'), label='Transifex Client',
+    module=__name__, name='tx', path=DEFAULT_TX_PATH
+)
 PythonDependency(
     module=__name__, environment=environment_development, name='devpi-server',
     version_string='==6.2.0'
@@ -191,10 +204,6 @@ PythonDependency(
     environment=environment_development,
     module=__name__, name='safety', version_string='==1.10.3'
 )
-PythonDependency(
-    environment=environment_development,
-    module=__name__, name='transifex-client', version_string='==0.14.3'
-)
 
 # Build
 
@@ -203,8 +212,8 @@ PythonDependency(
     version_string='==3.4.2'
 )
 PythonDependency(
-    environment=environment_build, module=__name__, name='wheel',
-    version_string='==0.37.0'
+    environments=(environment_build, environment_documentation),
+    module=__name__, name='wheel', version_string='==0.37.0'
 )
 
 # Documentation
@@ -237,3 +246,7 @@ PythonDependency(
     environment=environment_documentation, module=__name__, name='tornado',
     version_string='==6.1'
 )
+PythonDependency(
+    environment=environment_documentation_override, module=__name__,
+    name='jinja2', version_string='==3.0.3'
+)
