@@ -8,11 +8,14 @@ DEFAULT_COMMON_COLLAPSE_LIST_MENU_LIST_FACET = False
 DEFAULT_COMMON_COLLAPSE_LIST_MENU_OBJECT = False
 DEFAULT_COMMON_DISABLED_APPS = settings.COMMON_DISABLED_APPS
 DEFAULT_COMMON_EXTRA_APPS = settings.COMMON_EXTRA_APPS
+DEFAULT_COMMON_EXTRA_APPS_PRE = settings.COMMON_EXTRA_APPS_PRE
 DEFAULT_COMMON_HOME_VIEW = 'common:home'
 DEFAULT_COMMON_HOME_VIEW_DASHBOARD_NAME = 'user'
 DEFAULT_COMMON_PROJECT_TITLE = mayan.__title__
 DEFAULT_COMMON_PROJECT_URL = mayan.__website__
 
+DEFAULT_TX_PATH = '/usr/local/bin/tx'
+
 DJANGO_SQLITE_BACKEND = 'django.db.backends.sqlite3'
 
 MESSAGE_DEPRECATION_WARNING = _(
