@@ -9,7 +9,6 @@ except ImportError:
 
 from django.core.exceptions import ValidationError
 from django.core.validators import RegexValidator
-from django.utils import six
 from django.utils.deconstruct import deconstructible
 from django.utils.functional import SimpleLazyObject
 from django.utils.translation import ugettext_lazy as _
@@ -19,7 +18,7 @@ def _lazy_re_compile(regex, flags=0):
     """Lazily compile a regex with flags."""
     def _compile():
         # Compile the regex if it was not passed pre-compiled.
-        if isinstance(regex, six.string_types):
+        if isinstance(regex, str):
             return re.compile(regex, flags)
         else:
             assert not flags, 'flags must be empty if regex is passed pre-compiled'
