@@ -1,6 +1,6 @@
 from django.db import models, migrations
 
-import mayan.apps.converter.validators
+import mayan.apps.common.validators
 
 
 class Migration(migrations.Migration):
@@ -16,7 +16,7 @@ class Migration(migrations.Migration):
                 help_text='Enter the arguments for the transformation as a '
                 'YAML dictionary. ie: {"degrees": 180}', blank=True,
                 verbose_name='Arguments',
-                validators=[mayan.apps.converter.validators.YAMLValidator()]
+                validators=[mayan.apps.common.validators.YAMLValidator()]
             ),
             preserve_default=True,
         ),
