@@ -11,6 +11,10 @@ class Dashboard:
     def get(cls, name):
         return cls._registry[name]
 
+    @classmethod
+    def get_all(cls):
+        return sorted(cls._registry.values(), key=lambda x: x.label)
+
     def __init__(self, name, label):
         self.name = name
         self.label = label
@@ -47,7 +51,7 @@ class Dashboard:
 
         return loader.render_to_string(
             template_name='dashboards/dashboard.html', context={
-                'widgets': rendered_widgets
+                'dashboard': self, 'widgets': rendered_widgets
             }
         )
 
@@ -69,13 +73,21 @@ class BaseDashboardWidget:
     def register(cls, klass):
         cls._registry[klass.name] = klass
 
+    def get_base_context(self):
+        raise NotImplementedError
+
     def get_context(self):
-        return self.context
+        return {}
 
     def render(self, request):
+        self.request = request
+        context = self.get_base_context()
+        context.update(self.get_context())
+        context.update({'request': request})
+
         if self.template_name:
             return loader.render_to_string(
-                template_name=self.template_name, context=self.get_context(),
+                template_name=self.template_name, context=context,
             )
 
 
@@ -87,12 +99,32 @@ class DashboardWidgetNumeric(BaseDashboardWidget):
     link_icon = icon_dashboard_link_icon
     template_name = 'dashboards/numeric_widget.html'
 
-    def get_context(self):
+    def get_base_context(self):
         return {
-            'count': intcomma(value=self.count),
+            'count': intcomma(value=self.get_count()),
             'count_raw': self.count,
             'icon': self.icon,
             'label': self.label,
             'link': self.link,
             'link_icon': self.link_icon
         }
+
+
+class DashboardWidgetList(BaseDashboardWidget):
+    columns = None
+    icon = None
+    label = None
+    link = None
+    link_icon = icon_dashboard_link_icon
+    object_list_length = 10
+    template_name = 'dashboards/widget_list.html'
+
+    def get_base_context(self):
+        return {
+            'columns': self.columns or (),
+            'object_list': self.get_object_list()[:self.object_list_length],
+            'icon': self.icon,
+            'label': self.label,
+            'link': self.link,
+            'link_icon': self.link_icon
+        }
