@@ -16,3 +16,7 @@ class KeySerializer(serializers.ModelSerializer):
             'id', 'key_data', 'key_type', 'length', 'url', 'user_id'
         )
         model = Key
+        read_only_fields = (
+            'algorithm', 'creation_date', 'expiration_date', 'fingerprint',
+            'id', 'key_type', 'length', 'url', 'user_id'
+        )
