@@ -6,47 +6,32 @@ from django.db import OperationalError
 from mayan.apps.lock_manager.exceptions import LockError
 from mayan.celery import app
 
-from .settings import setting_task_retry
-
 logger = logging.getLogger(name=__name__)
 
 
-@app.task(
-    bind=True, default_retry_delay=setting_task_retry.value, max_retries=None,
-    ignore_result=True
-)
-def task_delete_empty(self):
-    IndexInstanceNode = apps.get_model(
-        app_label='document_indexing', model_name='IndexInstanceNode'
-    )
-
-    try:
-        IndexInstanceNode.objects.delete_empty()
-    except LockError as exception:
-        raise self.retry(exc=exception)
-
+# Index instance
 
 @app.task(
-    bind=True, default_retry_delay=setting_task_retry.value, max_retries=None,
-    ignore_result=True
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True,
+    retry_backoff_max=60
 )
-def task_index_document(self, document_id):
+def task_index_instance_document_add(self, document_id):
     Document = apps.get_model(
         app_label='documents', model_name='Document'
     )
-    IndexTemplate = apps.get_model(
-        app_label='document_indexing', model_name='IndexTemplate'
+    IndexInstance = apps.get_model(
+        app_label='document_indexing', model_name='IndexInstance'
     )
 
     try:
         document = Document.objects.get(pk=document_id)
     except Document.DoesNotExist:
-        # Document was deleted before we could execute, abort about
-        # updating
-        pass
+        """
+        Document was deleted before we could execute, abort about updating.
+        """
     else:
         try:
-            IndexTemplate.objects.index_document(document=document)
+            IndexInstance.objects.document_add(document=document)
         except OperationalError as exception:
             logger.warning(
                 'Operational error while trying to index document: '
@@ -62,10 +47,51 @@ def task_index_document(self, document_id):
 
 
 @app.task(
-    bind=True, default_retry_delay=setting_task_retry.value,
-    ignore_result=True
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True
 )
-def task_rebuild_index(self, index_id):
+def task_index_instance_document_remove(self, document_id):
+    Document = apps.get_model(
+        app_label='documents', model_name='Document'
+    )
+    IndexInstance = apps.get_model(
+        app_label='document_indexing', model_name='IndexInstance'
+    )
+
+    try:
+        document = Document.objects.get(pk=document_id)
+    except Document.DoesNotExist:
+        # Document was deleted before we could execute
+        # Since it was automatically removed from the document M2M
+        # we just now delete the empty instance nodes
+        try:
+            IndexInstance.objects.delete_empty_nodes()
+        except LockError as exception:
+            raise self.retry(exc=exception)
+    else:
+        try:
+            IndexInstance.objects.document_remove(document=document)
+        except LockError as exception:
+            raise self.retry(exc=exception)
+
+
+@app.task(
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True
+)
+def task_index_instance_node_delete_empty(self):
+    IndexInstance = apps.get_model(
+        app_label='document_indexing', model_name='IndexInstance'
+    )
+
+    try:
+        IndexInstance.objects.delete_empty_nodes()
+    except LockError as exception:
+        raise self.retry(exc=exception)
+
+
+# Index template
+
+@app.task(bind=True, ignore_result=True, retry_backoff=True)
+def task_index_template_rebuild(self, index_id):
     IndexTemplate = apps.get_model(
         app_label='document_indexing', model_name='IndexTemplate'
     )
@@ -76,32 +102,3 @@ def task_rebuild_index(self, index_id):
     except LockError as exception:
         # This index is being rebuilt by another task, retry later
         raise self.retry(exc=exception)
-
-
-@app.task(
-    bind=True, default_retry_delay=setting_task_retry.value, max_retries=None,
-    ignore_result=True
-)
-def task_remove_document(self, document_id):
-    Document = apps.get_model(
-        app_label='documents', model_name='Document'
-    )
-    IndexInstanceNode = apps.get_model(
-        app_label='document_indexing', model_name='IndexInstanceNode'
-    )
-
-    try:
-        document = Document.objects.get(pk=document_id)
-    except Document.DoesNotExist:
-        # Document was deleted before we could execute
-        # Since it was automatically removed from the document M2M
-        # we just now delete the empty instance nodes
-        try:
-            IndexInstanceNode.objects.delete_empty()
-        except LockError as exception:
-            raise self.retry(exc=exception)
-    else:
-        try:
-            IndexInstanceNode.objects.remove_document(document=document)
-        except LockError as exception:
-            raise self.retry(exc=exception)
