@@ -1,9 +1,3 @@
-from datetime import timedelta
-
-from django.utils.timezone import now
-
-from mayan.apps.common.settings import settings_db_sync_task_delay
-
 from .events import event_parsing_document_file_submitted
 from .tasks import task_parse_document_file
 
@@ -26,6 +20,5 @@ def method_document_file_parsing_submit(self, _user=None):
         user_id = None
 
     task_parse_document_file.apply_async(
-        eta=now() + timedelta(seconds=settings_db_sync_task_delay.value),
         kwargs={'document_file_pk': self.pk, 'user_id': user_id}
     )
