@@ -7,9 +7,11 @@ class DocumentFilePageContentSerializer(serializers.ModelSerializer):
     class Meta:
         fields = ('content',)
         model = DocumentFilePageContent
+        read_only_fields = ('content',)
 
 
 class DocumentTypeParsingSettingsSerializer(serializers.ModelSerializer):
     class Meta:
         fields = ('auto_parsing',)
         model = DocumentTypeSettings
+        read_only_fields = ()
