@@ -1,5 +1,7 @@
 from mayan.apps.appearance.classes import Icon
 
+# Tools
+
 icon_document_file_all_signature_refresh = Icon(
     driver_name='fontawesome-dual', primary_symbol='file-signature',
     secondary_symbol='recycle'
@@ -7,24 +9,33 @@ icon_document_file_all_signature_refresh = Icon(
 icon_document_file_all_signature_verify = Icon(
     driver_name='fontawesome', symbol='file-signature'
 )
-icon_document_file_signature_delete = Icon(
-    driver_name='fontawesome', symbol='times'
-)
-icon_document_file_signature_details = Icon(
-    driver_name='fontawesome', symbol='file-signature'
-)
+
+# Detached signature
+
 icon_document_file_signature_detached_create = Icon(
     driver_name='fontawesome', symbol='file-signature'
 )
-icon_document_file_signature_download = Icon(
+icon_document_file_signature_detached_delete = Icon(
+    driver_name='fontawesome', symbol='times'
+)
+icon_document_file_signature_detached_download = Icon(
     driver_name='fontawesome', symbol='download'
 )
+icon_document_file_signature_detached_upload = Icon(
+    driver_name='fontawesome', symbol='upload'
+)
+
+# Embedded
+
 icon_document_file_signature_embedded_create = Icon(
     driver_name='fontawesome', symbol='file-signature'
 )
+
+# All signatures
+
+icon_document_file_signature_details = Icon(
+    driver_name='fontawesome', symbol='file-signature'
+)
 icon_document_file_signature_list = Icon(
     driver_name='fontawesome', symbol='file-signature'
 )
-icon_document_file_signature_upload = Icon(
-    driver_name='fontawesome', symbol='upload'
-)
