@@ -1,10 +1,11 @@
-import os
-
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.smart_settings.classes import SettingNamespace
 
+from .literals import (
+    DEFAULT_SIGNATURES_STORAGE_BACKEND,
+    DEFAULT_SIGNATURES_STORAGE_BACKEND_ARGUMENTS
+)
 from .setting_migrations import DocumentSignaturesSettingMigration
 
 namespace = SettingNamespace(
@@ -14,17 +15,15 @@ namespace = SettingNamespace(
 )
 
 setting_storage_backend = namespace.add_setting(
-    default='django.core.files.storage.FileSystemStorage',
+    default=DEFAULT_SIGNATURES_STORAGE_BACKEND,
     global_name='SIGNATURES_STORAGE_BACKEND', help_text=_(
         'Path to the Storage subclass to use when storing detached '
         'signatures.'
     )
 )
 setting_storage_backend_arguments = namespace.add_setting(
-    global_name='SIGNATURES_STORAGE_BACKEND_ARGUMENTS',
-    default={
-        'location': os.path.join(settings.MEDIA_ROOT, 'document_signatures')
-    }, help_text=_(
+    default=DEFAULT_SIGNATURES_STORAGE_BACKEND_ARGUMENTS,
+    global_name='SIGNATURES_STORAGE_BACKEND_ARGUMENTS', help_text=_(
         'Arguments to pass to the SIGNATURE_STORAGE_BACKEND.'
     )
 )
