@@ -52,11 +52,17 @@ class WorkflowTemplateSerializer(serializers.HyperlinkedModelSerializer):
             }
         }
         fields = (
-            'document_types_add_url', 'document_types_remove_url',
-            'document_types_url', 'id', 'image_url', 'internal_name',
-            'label', 'states_url', 'transitions_url', 'url'
+            'auto_launch', 'document_types_add_url',
+            'document_types_remove_url', 'document_types_url', 'id',
+            'image_url', 'internal_name', 'label', 'states_url',
+            'transitions_url', 'url'
         )
         model = Workflow
+        read_only_fields = (
+            'document_types_add_url', 'document_types_remove_url',
+            'document_types_url', 'id', 'image_url', 'states_url',
+            'transitions_url', 'url'
+        )
 
 
 class WorkflowTemplateDocumentTypeAddSerializer(serializers.Serializer):
@@ -115,6 +121,7 @@ class WorkflowTemplateStateSerializer(serializers.HyperlinkedModelSerializer):
             'workflow_template_url'
         )
         model = WorkflowState
+        read_only_fields = ('id', 'url', 'workflow_template_url')
 
 
 class WorkflowTemplateStateActionSerializer(serializers.HyperlinkedModelSerializer):
@@ -208,6 +215,9 @@ class WorkflowTransitionFieldSerializer(
             'workflow_transition_url'
         )
         model = WorkflowTransitionField
+        read_only_fields = (
+            'id', 'url', 'workflow_template_url', 'workflow_transition_url'
+        )
 
 
 class WorkflowTemplateTransitionSerializer(
@@ -233,16 +243,13 @@ class WorkflowTemplateTransitionSerializer(
 
     class Meta:
         fields = (
-            'condition', 'destination_state', 'field_list_url', 'id', 'label',
-            'origin_state', 'url', 'workflow_template_url',
-
-            'destination_state_id',
-            'origin_state_id'
+            'condition', 'destination_state', 'destination_state_id',
+            'field_list_url', 'id', 'label', 'origin_state',
+            'origin_state_id', 'url', 'workflow_template_url'
         )
         model = WorkflowTransition
         read_only_fields = (
-            'destination_state', 'field_list_url', 'id', 'origin_state',
-            'url', 'workflow_template_url'
+            'field_list_url', 'id', 'url', 'workflow_template_url'
         )
 
     def create(self, validated_data):
@@ -362,6 +369,10 @@ class WorkflowInstanceLogEntrySerializer(serializers.ModelSerializer):
             'workflow_instance_url', 'workflow_template_url'
         )
         model = WorkflowInstanceLogEntry
+        read_only_fields = (
+            'datetime', 'document_url', 'id', 'transition',
+            'url', 'user', 'workflow_instance_url', 'workflow_template_url'
+        )
 
     def create(self, validated_data):
         return self.context['workflow_instance'].do_transition(
@@ -413,7 +424,7 @@ class WorkflowInstanceSerializer(serializers.ModelSerializer):
             'workflow_template_url'
         )
         model = WorkflowInstance
-        read_only_field = fields
+        read_only_fields = fields
 
     def get_document_url(self, instance):
         return reverse(
