@@ -16,8 +16,6 @@ TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEMPLATE_DATA = {
     'document_description': TEST_DOCUMENT_EDIT_WORKFLOW_TEMPLATE_STATE_ACTION_TEMPLATE_DESCRIPTION
 }
 
-TEST_INDEX_TEMPLATE_LABEL = 'test workflow index'
-
 TEST_HEADERS_KEY = 'test key'
 TEST_HEADERS_VALUE = 'test value'
 TEST_HEADERS_JSON = '{{"{}": "{}"}}'.format(
@@ -38,7 +36,7 @@ TEST_SERVER_PASSWORD = 'testpassword'
 TEST_WORKFLOW_INSTANCE_LOG_ENTRY_COMMENT = 'test workflow instance log entry comment'
 TEST_WORKFLOW_INSTANCE_LOG_ENTRY_EXTRA_DATA = '{"test": "test"}'
 TEST_WORKFLOW_TEMPLATE_LABEL = 'test workflow template label'
-TEST_WORKFLOW_TEMPLATE_INTERNAL_NAME = 'test_workflow_template_label'
+TEST_WORKFLOW_TEMPLATE_INTERNAL_NAME = 'test_workflow_template_name'
 TEST_WORKFLOW_TEMPLATE_LABEL_EDITED = 'test workflow template label edited'
 TEST_WORKFLOW_TEMPLATE_INITIAL_STATE_LABEL = 'test initial state'
 TEST_WORKFLOW_TEMPLATE_INITIAL_STATE_COMPLETION = 33
