@@ -1,6 +1,5 @@
 from rest_framework import status
 
-from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.rest_api.tests.base import BaseAPITestCase
 
 from ..events import event_workflow_template_edited
@@ -14,11 +13,9 @@ from .mixins.workflow_template_state_mixins import WorkflowTemplateStateAPIViewT
 
 
 class WorkflowTemplateStatesAPIViewTestCase(
-    DocumentTestMixin, WorkflowTemplateStateAPIViewTestMixin,
-    WorkflowTemplateTestMixin, BaseAPITestCase
+    WorkflowTemplateStateAPIViewTestMixin, WorkflowTemplateTestMixin,
+    BaseAPITestCase
 ):
-    auto_upload_test_document = False
-
     def setUp(self):
         super().setUp()
         self._create_test_workflow_template()
