@@ -24,7 +24,7 @@ class Migration(migrations.Migration):
     ]
 
     def __init__(self, *args, **kwargs):
-        super(Migration, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if connection.vendor == 'postgresql':
             self.operations.insert(
