@@ -7,7 +7,10 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.databases.model_mixins import ExtraDataModelMixin
 
-from ..managers import FavoriteDocumentManager
+from ..managers import (
+    FavoriteDocumentManager, ValidFavoriteDocumentProxyManager,
+    ValidFavoriteDocumentManager
+)
 
 from .document_models import Document
 
@@ -32,6 +35,7 @@ class FavoriteDocument(ExtraDataModelMixin, models.Model):
     )
 
     objects = FavoriteDocumentManager()
+    valid = ValidFavoriteDocumentManager()
 
     class Meta:
         ordering = ('datetime_added',)
@@ -44,3 +48,11 @@ class FavoriteDocument(ExtraDataModelMixin, models.Model):
     def natural_key(self):
         return (self.document.natural_key(), self.user.natural_key())
     natural_key.dependencies = ['documents.Document', settings.AUTH_USER_MODEL]
+
+
+class FavoriteDocumentProxy(Document):
+    objects = models.Manager()
+    valid = ValidFavoriteDocumentProxyManager()
+
+    class Meta:
+        proxy = True
