@@ -67,6 +67,28 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(events[0].target, self.test_document_version)
         self.assertEqual(events[0].verb, event_document_version_created.id)
 
+    def test_trashed_document_version_create_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_create
+        )
+
+        document_version_count = self.test_document.versions.count()
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_create_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.assertEqual(
+            self.test_document.versions.count(), document_version_count
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_delete_api_view_no_permission(self):
         document_version_count = self.test_document.versions.count()
 
@@ -106,6 +128,28 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(events[0].target, self.test_document)
         self.assertEqual(events[0].verb, event_document_version_deleted.id)
 
+    def test_trashed_document_version_delete_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_delete
+        )
+
+        document_version_count = self.test_document.versions.count()
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_delete_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.assertEqual(
+            self.test_document.versions.count(), document_version_count
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_detail_api_view_no_permission(self):
         self._clear_events()
 
@@ -133,6 +177,22 @@ class DocumentVersionAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
+    def test_trashed_document_version_detail_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_view
+        )
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_detail_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_edit_via_patch_api_view_no_permission(self):
         document_version_comment = self.test_document.version_active.comment
 
@@ -171,11 +231,36 @@ class DocumentVersionAPIViewTestCase(
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
+
         self.assertEqual(events[0].action_object, self.test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self.test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
+    def test_trashed_document_version_edit_via_patch_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_edit
+        )
+
+        document_version_comment = self.test_document.version_active.comment
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_edit_via_patch_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.test_document.version_active.refresh_from_db()
+        self.assertEqual(
+            self.test_document.version_active.comment,
+            document_version_comment
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_edit_via_put_api_view_no_permission(self):
         document_version_comment = self.test_document.version_active.comment
 
@@ -219,6 +304,30 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(events[0].target, self.test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
+    def test_trashed_document_version_edit_via_put_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_edit
+        )
+
+        document_version_comment = self.test_document.version_active.comment
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_edit_via_put_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.test_document.version_active.refresh_from_db()
+        self.assertEqual(
+            self.test_document.version_active.comment,
+            document_version_comment
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_list_api_view_no_permission(self):
         self._clear_events()
 
@@ -247,6 +356,22 @@ class DocumentVersionAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
+    def test_trashed_document_version_list_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_view
+        )
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
 
 class DocumentVersionExportAPIViewTestCase(
     DocumentVersionAPIViewTestMixin, DocumentTestMixin,
@@ -294,6 +419,31 @@ class DocumentVersionExportAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
+    def test_trashed_document_version_export_api_view_via_get_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_export
+        )
+        download_file_count = DownloadFile.objects.count()
+        message_count = Message.objects.count()
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_export_api_view_via_get()
+        self.assertEqual(
+            response.status_code, status.HTTP_405_METHOD_NOT_ALLOWED
+        )
+
+        self.assertEqual(
+            DownloadFile.objects.count(), download_file_count
+        )
+        self.assertEqual(Message.objects.count(), message_count)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
     def test_document_version_export_api_view_via_post_no_permission(self):
         download_file_count = DownloadFile.objects.count()
         message_count = Message.objects.count()
@@ -349,3 +499,24 @@ class DocumentVersionExportAPIViewTestCase(
         self.assertEqual(events[2].actor, test_message)
         self.assertEqual(events[2].target, test_message)
         self.assertEqual(events[2].verb, event_message_created.id)
+
+    def test_trashed_document_version_export_api_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document,
+            permission=permission_document_version_export
+        )
+        download_file_count = DownloadFile.objects.count()
+
+        self.test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_export_api_view_via_post()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.assertEqual(
+            DownloadFile.objects.count(), download_file_count
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
