@@ -11,7 +11,9 @@ DEFAULT_SCOPE_ID = '0'
 
 DELIMITER = '_'
 
-SEARCH_MODEL_NAME_KWARG = 'search_model_name'
+QUERY_PARAMETER_ANY_FIELD = 'q'
+
+SEARCH_MODEL_NAME_KWARG = 'search_model_pk'
 
 SCOPE_MARKER = '__'
 SCOPE_MATCH_ALL = 'match_all'
