@@ -6,12 +6,13 @@ from mayan.apps.lock_manager.exceptions import LockError
 from mayan.celery import app
 
 from .classes import SearchBackend, SearchModel
-from .literals import TASK_RETRY_DELAY
 
 logger = logging.getLogger(name=__name__)
 
 
-@app.task(bind=True, default_retry_delay=TASK_RETRY_DELAY, max_retries=None, ignore_result=True)
+@app.task(
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True
+)
 def task_deindex_instance(self, app_label, model_name, object_id):
     logger.info('Executing')
 
@@ -23,10 +24,12 @@ def task_deindex_instance(self, app_label, model_name, object_id):
     except LockError as exception:
         raise self.retry(exc=exception)
 
-    logger.info('Finshed')
+    logger.info('Finished')
 
 
-@app.task(bind=True, default_retry_delay=TASK_RETRY_DELAY, max_retries=None, ignore_result=True)
+@app.task(
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True
+)
 def task_index_search_model(self, search_model_full_name):
     search_model = SearchModel.get(name=search_model_full_name)
 
@@ -40,14 +43,19 @@ def task_index_search_model(self, search_model_full_name):
         )
 
 
-@app.task(bind=True, default_retry_delay=TASK_RETRY_DELAY, max_retries=None, ignore_result=True)
+@app.task(
+    bind=True, ignore_result=True, max_retries=None, retry_backoff=True
+)
 def task_index_instance(self, app_label, model_name, object_id):
     logger.info('Executing')
 
     try:
         Model = apps.get_model(app_label=app_label, model_name=model_name)
     except LookupError:
-        """Non fatal, just exit the task."""
+        """
+        The app or model does not exists anymore. Non fatal, just exit
+        the task.
+        """
     else:
         try:
             instance = Model._meta.default_manager.get(pk=object_id)
@@ -62,4 +70,4 @@ def task_index_instance(self, app_label, model_name, object_id):
             except LockError as exception:
                 raise self.retry(exc=exception)
 
-    logger.info('Finshed')
+    logger.info('Finished')
