@@ -7,6 +7,8 @@ from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.tags.tests.mixins import TagTestMixin
 from mayan.apps.testing.tests.base import BaseTestCase
 
+from ..literals import QUERY_PARAMETER_ANY_FIELD
+
 from .mixins import SearchTestMixin
 
 
@@ -146,7 +148,8 @@ class DjangoSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'OR first'}, user=self._test_case_user
+            query={QUERY_PARAMETER_ANY_FIELD: 'OR first'},
+            user=self._test_case_user
         )
 
         self.assertEqual(queryset.count(), 1)
@@ -162,7 +165,8 @@ class DjangoSearchBackendDocumentSearchTestCase(
         )
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'first OR second'}, user=self._test_case_user
+            query={QUERY_PARAMETER_ANY_FIELD: 'first OR second'},
+            user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 2)
         self.assertTrue(self.test_documents[0] in queryset)
@@ -197,14 +201,14 @@ class DjangoSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'non_valid second'},
+            query={QUERY_PARAMETER_ANY_FIELD: 'non_valid second'},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'second non_valid'},
+            query={QUERY_PARAMETER_ANY_FIELD: 'second non_valid'},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
@@ -218,7 +222,7 @@ class DjangoSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': '-non_valid second'},
+            query={QUERY_PARAMETER_ANY_FIELD: '-non_valid second'},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 1)
@@ -289,7 +293,8 @@ class WhooshSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'first*'}, user=self._test_case_user
+            query={QUERY_PARAMETER_ANY_FIELD: 'first*'},
+            user=self._test_case_user
         )
 
         self.assertEqual(queryset.count(), 1)
@@ -303,7 +308,8 @@ class WhooshSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'OR first*'}, user=self._test_case_user
+            query={QUERY_PARAMETER_ANY_FIELD: 'OR first*'},
+            user=self._test_case_user
         )
 
         self.assertEqual(queryset.count(), 1)
@@ -319,7 +325,8 @@ class WhooshSearchBackendDocumentSearchTestCase(
         )
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'first* OR second*'}, user=self._test_case_user
+            query={QUERY_PARAMETER_ANY_FIELD: 'first* OR second*'},
+            user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 2)
         self.assertTrue(self.test_documents[0] in queryset)
@@ -354,14 +361,14 @@ class WhooshSearchBackendDocumentSearchTestCase(
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'non_valid AND second*'},
+            query={QUERY_PARAMETER_ANY_FIELD: 'non_valid AND second*'},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
 
         queryset = self.search_backend.search(
             search_model=document_search,
-            query={'q': 'second* AND non_valid'},
+            query={QUERY_PARAMETER_ANY_FIELD: 'second* AND non_valid'},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
