@@ -7,6 +7,7 @@ from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..classes import SearchBackend, SearchModel
+from ..literals import QUERY_PARAMETER_ANY_FIELD, SEARCH_MODEL_NAME_KWARG
 from ..permissions import permission_search_tools
 
 from .mixins import (
@@ -15,7 +16,7 @@ from .mixins import (
 
 
 class AdvancedSearchViewTestCaseMixin(
-    DocumentTestMixin, SearchViewTestMixin, GenericViewTestCase
+    DocumentTestMixin, SearchViewTestMixin
 ):
     auto_upload_test_document = False
 
@@ -49,7 +50,7 @@ class AdvancedSearchViewTestCaseMixin(
             # Functional test for the first page of advanced results
             response = self._request_search_results_view(
                 data={'label': test_document_label}, kwargs={
-                    'search_model_name': document_search.get_full_name()
+                    SEARCH_MODEL_NAME_KWARG: document_search.get_full_name()
                 }
             )
 
@@ -69,7 +70,7 @@ class AdvancedSearchViewTestCaseMixin(
             # Functional test for the second page of advanced results
             response = self._request_search_results_view(
                 data={'label': test_document_label, 'page': 2}, kwargs={
-                    'search_model_name': document_search.get_full_name()
+                    SEARCH_MODEL_NAME_KWARG: document_search.get_full_name()
                 }
             )
             # Total (3 - 4 out of 4) (Page 2 of 2)
@@ -111,7 +112,7 @@ class SearchViewTestCaseMixin(
         response = self._request_search_results_view(
             data={
                 'label': self.test_document.label,
-                '_search_model_name': document_search.get_full_name()
+                '_{}'.format(SEARCH_MODEL_NAME_KWARG): document_search.get_full_name()
             }
         )
         self.assertContains(
@@ -158,7 +159,7 @@ class SearchToolsViewTestCase(
 
         queryset = self.search_backend.search(
             search_model=self.document_search_model,
-            query={'q': self.test_document.label},
+            query={QUERY_PARAMETER_ANY_FIELD: self.test_document.label},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
@@ -177,7 +178,7 @@ class SearchToolsViewTestCase(
 
         queryset = self.search_backend.search(
             search_model=self.document_search_model,
-            query={'q': self.test_document.label},
+            query={QUERY_PARAMETER_ANY_FIELD: self.test_document.label},
             user=self._test_case_user
         )
         self.assertNotEqual(queryset.count(), 0)
