@@ -1,11 +1,9 @@
-from django.contrib.contenttypes.models import ContentType
 from django.http import Http404
-from django.shortcuts import get_object_or_404
 
 from actstream.models import Action, any_stream
 
-from mayan.apps.acls.models import AccessControlList
 from mayan.apps.rest_api import generics
+from mayan.apps.rest_api.api_view_mixins import ExternalContentTypeObjectAPIViewMixin
 
 from .classes import EventType, EventTypeNamespace
 from .models import Notification
@@ -16,35 +14,20 @@ from .serializers import (
 )
 
 
-class APIObjectEventListView(generics.ListAPIView):
+class APIObjectEventListView(
+    ExternalContentTypeObjectAPIViewMixin, generics.ListAPIView
+):
     """
     get: Return a list of events for the specified object.
     """
+    mayan_external_object_permissions = {
+        'GET': (permission_events_view,),
+    }
     ordering_fields = ('id', 'timestamp')
     serializer_class = EventSerializer
 
-    def get_object(self):
-        content_type = get_object_or_404(
-            klass=ContentType, app_label=self.kwargs['app_label'],
-            model=self.kwargs['model']
-        )
-
-        try:
-            return content_type.get_object_for_this_type(
-                pk=self.kwargs['object_id']
-            )
-        except content_type.model_class().DoesNotExist:
-            raise Http404
-
     def get_queryset(self):
-        obj = self.get_object()
-
-        AccessControlList.objects.check_access(
-            obj=obj, permissions=(permission_events_view,),
-            user=self.request.user
-        )
-
-        return any_stream(obj=obj)
+        return any_stream(obj=self.external_object)
 
 
 class APIEventTypeNamespaceDetailView(generics.RetrieveAPIView):
